.. highlight:: shell

============
Installation
============

At the command line::

    $ easy_install sqreen_python_agent

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv sqreen_python_agent
    $ pip install sqreen_python_agent
